Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/uhistogram_simpletest.py
    :caption: examples/uhistogram_simpletest.py
    :linenos:

Text Example
-------------

A more advance example to illustrate how to add text to the histogram

.. literalinclude:: ../examples/uhistogram_text_example.py
    :caption: examples/uhistogram_text_example.py
    :linenos:
